@@ -24,7 +24,7 @@
 
 #include <QtTest>
 
-Q_DECLARE_METATYPE(QList<qint64>);
+Q_DECLARE_METATYPE(QList<qint64>)
 
 class QuotaRootJobTest: public QObject
 {
@@ -156,7 +156,7 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP::Session session(QLatin1String("127.0.0.1"), 5989);
+        KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
         KIMAP::GetQuotaRootJob *job = new KIMAP::GetQuotaRootJob(&session);
         job->setMailBox(mailbox);
