@@ -21,9 +21,9 @@
     Boston, MA 02110-1301, USA.
   */
 
-#include <QtCore/QEventLoop>
-#include <QtCore/QObject>
-#include <QtTest/QtTest>
+#include <QEventLoop>
+#include <QObject>
+#include <QtTest>
 
 #include "session.h"
 #include "job.h"
