@@ -29,7 +29,7 @@ namespace KIMAP
 {
 
 class Session;
-struct Message;
+struct Response;
 class AppendJobPrivate;
 
 /**
@@ -125,8 +125,8 @@ public:
     qint64 uid() const;
 
 protected:
-    void doStart() Q_DECL_OVERRIDE;
-    void handleResponse(const Message &response) Q_DECL_OVERRIDE;
+    void doStart() override;
+    void handleResponse(const Response &response) override;
 };
 
 }
