@@ -28,7 +28,7 @@ namespace KIMAP
 {
 
 class Session;
-struct Message;
+struct Response;
 class CapabilitiesJobPrivate;
 
 /**
@@ -70,8 +70,8 @@ Q_SIGNALS:
     void capabilitiesReceived(const QStringList &capabilities);
 
 protected:
-    void doStart() Q_DECL_OVERRIDE;
-    void handleResponse(const Message &response) Q_DECL_OVERRIDE;
+    void doStart() override;
+    void handleResponse(const Response &response) override;
 };
 
 }
