@@ -18,8 +18,8 @@
 */
 
 #include "imapset.h"
-#include "helper_p.h"
-#include <QtCore/QSharedData>
+
+#include <QSharedData>
 
 using namespace KIMAP;
 
@@ -243,7 +243,7 @@ void ImapSet::add(Id value)
 void ImapSet::add(const QVector<Id> &values)
 {
     QVector<Id> vals = values;
-    qSort(vals);
+    std::sort(vals.begin(), vals.end());
     for (int i = 0; i < vals.count(); ++i) {
         const int begin = vals[i];
         Q_ASSERT(begin >= 0);
