@@ -19,14 +19,15 @@
 
 #include "listjob.h"
 
-#include <QtCore/QTimer>
+#include <QTimer>
 #include <KLocalizedString>
 
 #include "job_p.h"
-#include "message_p.h"
+#include "response_p.h"
 #include "rfccodecs.h"
 #include "session_p.h"
 
+
 namespace KIMAP
 {
 class ListJobPrivate : public JobPrivate
@@ -145,7 +146,7 @@ void ListJob::doStart()
     if (d->namespaces.isEmpty()) {
         d->tags << d->sessionInternal()->sendCommand(d->command, "\"\" *");
     } else {
-        foreach (const MailBoxDescriptor &descriptor, d->namespaces) {
+        for (const MailBoxDescriptor &descriptor : qAsConst(d->namespaces)) {
             QString parameters = QStringLiteral("\"\" \"%1\"");
 
             if (descriptor.name.endsWith(descriptor.separator)) {
@@ -161,7 +162,7 @@ void ListJob::doStart()
     }
 }
 
-void ListJob::handleResponse(const Message &response)
+void ListJob::handleResponse(const Response &response)
 {
     Q_D(ListJob);
 
