@@ -28,7 +28,7 @@ namespace KIMAP
 {
 
 class Session;
-struct Message;
+struct Response;
 class SelectJobPrivate;
 
 class KIMAP_EXPORT SelectJob : public Job
@@ -86,8 +86,8 @@ public:
     bool condstoreEnabled() const;
 
 protected:
-    void doStart() Q_DECL_OVERRIDE;
-    void handleResponse(const Message &response) Q_DECL_OVERRIDE;
+    void doStart() override;
+    void handleResponse(const Response &response) override;
 };
 
 }
