@@ -24,15 +24,15 @@
 #include "session_p.h"
 #include "sessionuiproxy.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QTimer>
-#include <QtCore/QPointer>
+#include <QTimer>
+#include <QPointer>
 
 #include "kimap_debug.h"
 
 #include "job.h"
+#include "job_p.h"
 #include "loginjob.h"
-#include "message_p.h"
+#include "response_p.h"
 #include "sessionlogger_p.h"
 #include "sessionthread_p.h"
 #include "rfccodecs.h"
@@ -75,7 +75,7 @@ Session::~Session()
     //Make sure all jobs know we're done
     d->socketDisconnected();
     delete d->thread;
-    d->thread = Q_NULLPTR;
+    d->thread = nullptr;
 }
 
 void Session::setUiProxy(const SessionUiProxy::Ptr &proxy)
@@ -136,9 +136,12 @@ void SessionPrivate::handleSslError(const KSslErrorUiData &errorData)
 SessionPrivate::SessionPrivate(Session *session)
     : QObject(session),
       q(session),
+      isSocketConnected(false),
       state(Session::Disconnected),
-      logger(Q_NULLPTR),
-      currentJob(Q_NULLPTR),
+      logger(nullptr),
+      thread(nullptr),
+      jobRunning(false),
+      currentJob(nullptr),
       tagCount(0),
       sslVersion(KTcpSocket::UnknownSslVersion),
       socketTimerInterval(30000)   // By default timeouts on 30s
@@ -189,7 +192,7 @@ void SessionPrivate::jobDone(KJob *job)
     stopSocketTimer();
 
     jobRunning = false;
-    currentJob = Q_NULLPTR;
+    currentJob = nullptr;
     emit q->jobQueueSizeChanged(q->jobQueueSize());
     startNext();
 }
@@ -198,13 +201,13 @@ void SessionPrivate::jobDestroyed(QObject *job)
 {
     queue.removeAll(static_cast<KIMAP::Job *>(job));
     if (currentJob == job) {
-        currentJob = Q_NULLPTR;
+        currentJob = nullptr;
     }
 }
 
-void SessionPrivate::responseReceived(const Message &response)
+void SessionPrivate::responseReceived(const Response &response)
 {
-    if (logger && (state == Session::Authenticated || state == Session::Selected)) {
+    if (logger && isConnected()) {
         logger->dataReceived(response.toString());
     }
 
@@ -222,7 +225,7 @@ void SessionPrivate::responseReceived(const Message &response)
     // BYE may arrive as part of a LOGOUT sequence or before the server closes the connection after an error.
     // In any case we should wait until the server closes the connection, so we don't have to do anything.
     if (code == "BYE") {
-        Message simplified = response;
+        Response simplified = response;
         if (simplified.content.size() >= 2) {
             simplified.content.removeFirst(); // Strip the tag
             simplified.content.removeFirst(); // Strip the code
@@ -239,7 +242,7 @@ void SessionPrivate::responseReceived(const Message &response)
         if (code == "OK") {
             setState(Session::NotAuthenticated);
 
-            Message simplified = response;
+            Response simplified = response;
             simplified.content.removeFirst(); // Strip the tag
             simplified.content.removeFirst(); // Strip the code
             greeting = simplified.toString().trimmed(); // Save the server greeting
@@ -248,7 +251,7 @@ void SessionPrivate::responseReceived(const Message &response)
         } else if (code == "PREAUTH") {
             setState(Session::Authenticated);
 
-            Message simplified = response;
+            Response simplified = response;
             simplified.content.removeFirst(); // Strip the tag
             simplified.content.removeFirst(); // Strip the code
             greeting = simplified.toString().trimmed(); // Save the server greeting
@@ -291,7 +294,7 @@ void SessionPrivate::responseReceived(const Message &response)
     }
 
     // If a job is running forward it the response
-    if (currentJob != Q_NULLPTR) {
+    if (currentJob != nullptr) {
         restartSocketTimer();
         currentJob->handleResponse(response);
     } else {
@@ -339,7 +342,7 @@ void SessionPrivate::sendData(const QByteArray &data)
 {
     restartSocketTimer();
 
-    if (logger && (state == Session::Authenticated || state == Session::Selected)) {
+    if (logger && isConnected()) {
         logger->dataSent(data);
     }
 
@@ -371,13 +374,18 @@ void SessionPrivate::socketConnected()
     }
 }
 
+bool SessionPrivate::isConnected() const
+{
+    return state == Session::Authenticated || state == Session::Selected;
+}
+
 void SessionPrivate::socketDisconnected()
 {
     if (socketTimer.isActive()) {
         stopSocketTimer();
     }
 
-    if (logger && (state == Session::Authenticated || state == Session::Selected)) {
+    if (logger && isConnected()) {
         logger->disconnectionOccured();
     }
 
@@ -405,10 +413,10 @@ void SessionPrivate::socketError(KTcpSocket::Error error)
     }
 
     if (currentJob) {
-        currentJob->setSocketError(error);
+        currentJob->d_ptr->setSocketError(error);
     } else if (!queue.isEmpty()) {
         currentJob = queue.takeFirst();
-        currentJob->setSocketError(error);
+        currentJob->d_ptr->setSocketError(error);
     }
 
     if (isSocketConnected) {
