@@ -23,7 +23,7 @@
 #include "kimap_debug.h"
 
 #include "metadatajobbase_p.h"
-#include "message_p.h"
+#include "response_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
 
@@ -32,7 +32,7 @@ namespace KIMAP
 class SetMetaDataJobPrivate : public MetaDataJobBasePrivate
 {
 public:
-    SetMetaDataJobPrivate(Session *session, const QString &name) : MetaDataJobBasePrivate(session, name), metaDataErrors(Q_NULLPTR), maxAcceptedSize(-1) { }
+    SetMetaDataJobPrivate(Session *session, const QString &name) : MetaDataJobBasePrivate(session, name), metaDataErrors(nullptr), maxAcceptedSize(-1) { }
     ~SetMetaDataJobPrivate() { }
 
     QMap<QByteArray, QByteArray> entries;
@@ -57,8 +57,7 @@ SetMetaDataJob::~SetMetaDataJob()
 void SetMetaDataJob::doStart()
 {
     Q_D(SetMetaDataJob);
-    QByteArray parameters;
-    parameters = '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + "\" ";
+    QByteArray parameters = '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + "\" ";
     d->entriesIt = d->entries.constBegin();
 
     QByteArray command = "SETMETADATA";
@@ -106,7 +105,7 @@ void SetMetaDataJob::doStart()
 //   qCDebug(KIMAP_LOG) << "SENT: " << command << " " << parameters;
 }
 
-void SetMetaDataJob::handleResponse(const Message &response)
+void SetMetaDataJob::handleResponse(const Response &response)
 {
     Q_D(SetMetaDataJob);
 
@@ -116,20 +115,21 @@ void SetMetaDataJob::handleResponse(const Message &response)
         if (response.content[1].toString() == "NO") {
             setError(UserDefinedError);
             setErrorText(i18n("%1 failed, server replied: %2", d->m_name, QLatin1String(response.toString().constData())));
-            if (response.content[2].toString() == "[ANNOTATEMORE TOOMANY]" ||
-                    response.content[2].toString() == "[METADATA TOOMANY]") {
+            const QByteArray responseBa = response.content[2].toString();
+            if (responseBa == "[ANNOTATEMORE TOOMANY]" ||
+                    responseBa == "[METADATA TOOMANY]") {
                 d->metaDataErrors |= TooMany;
-            } else if (response.content[2].toString() == "[ANNOTATEMORE TOOBIG]" ||
-                       response.content[2].toString().startsWith("[METADATA MAXSIZE")) {    //krazy:exclude=strings
+            } else if (responseBa == "[ANNOTATEMORE TOOBIG]" ||
+                       responseBa.startsWith("[METADATA MAXSIZE")) {    //krazy:exclude=strings
                 d->metaDataErrors |= TooBig;
                 d->maxAcceptedSize = -1;
-                if (response.content[2].toString().startsWith("[METADATA MAXSIZE")) {     //krazy:exclude=strings
-                    QByteArray max = response.content[2].toString();
+                if (responseBa.startsWith("[METADATA MAXSIZE")) {     //krazy:exclude=strings
+                    QByteArray max = responseBa;
                     max.replace("[METADATA MAXSIZE", "");   //krazy:exclude=doublequote_chars
                     max.replace("]", "");                   //krazy:exclude=doublequote_chars
                     d->maxAcceptedSize = max.toLongLong();
                 }
-            } else if (response.content[2].toString() == "[METADATA NOPRIVATE]") {
+            } else if (responseBa == "[METADATA NOPRIVATE]") {
                 d->metaDataErrors |= NoPrivate;
             }
         } else if (response.content.size() < 2) {
