@@ -45,7 +45,7 @@ public:
     QString mailBox() const;
 
 protected:
-    void doStart() Q_DECL_OVERRIDE;
+    void doStart() override;
 };
 
 }
